# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.api_component_dtov2 import ApiComponentDTOV2
from sonatype_iq_api_client.models.api_constraint_violation_dto import ApiConstraintViolationDTO
from typing import Optional, Set
from typing_extensions import Self

class ApiPolicyViolationForDiffDTO(BaseModel):
    """
    ApiPolicyViolationForDiffDTO
    """ # noqa: E501
    component: Optional[ApiComponentDTOV2] = None
    constraint_violations: Optional[List[ApiConstraintViolationDTO]] = Field(default=None, alias="constraintViolations")
    fix_time: Optional[datetime] = Field(default=None, alias="fixTime")
    legacy_violation_time: Optional[datetime] = Field(default=None, alias="legacyViolationTime")
    open_time: Optional[datetime] = Field(default=None, alias="openTime")
    policy_id: Optional[StrictStr] = Field(default=None, alias="policyId")
    policy_name: Optional[StrictStr] = Field(default=None, alias="policyName")
    policy_violation_id: Optional[StrictStr] = Field(default=None, alias="policyViolationId")
    threat_level: Optional[StrictInt] = Field(default=None, alias="threatLevel")
    waive_time: Optional[datetime] = Field(default=None, alias="waiveTime")
    __properties: ClassVar[List[str]] = ["component", "constraintViolations", "fixTime", "legacyViolationTime", "openTime", "policyId", "policyName", "policyViolationId", "threatLevel", "waiveTime"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiPolicyViolationForDiffDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of component
        if self.component:
            _dict['component'] = self.component.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in constraint_violations (list)
        _items = []
        if self.constraint_violations:
            for _item_constraint_violations in self.constraint_violations:
                if _item_constraint_violations:
                    _items.append(_item_constraint_violations.to_dict())
            _dict['constraintViolations'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiPolicyViolationForDiffDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "component": ApiComponentDTOV2.from_dict(obj["component"]) if obj.get("component") is not None else None,
            "constraintViolations": [ApiConstraintViolationDTO.from_dict(_item) for _item in obj["constraintViolations"]] if obj.get("constraintViolations") is not None else None,
            "fixTime": obj.get("fixTime"),
            "legacyViolationTime": obj.get("legacyViolationTime"),
            "openTime": obj.get("openTime"),
            "policyId": obj.get("policyId"),
            "policyName": obj.get("policyName"),
            "policyViolationId": obj.get("policyViolationId"),
            "threatLevel": obj.get("threatLevel"),
            "waiveTime": obj.get("waiveTime")
        })
        return _obj


