# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.license_legal_metadata_template_api import LicenseLegalMetadataTemplateApi


class TestLicenseLegalMetadataTemplateApi(unittest.TestCase):
    """LicenseLegalMetadataTemplateApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LicenseLegalMetadataTemplateApi()

    def tearDown(self) -> None:
        pass

    def test_delete_attribution_report_template(self) -> None:
        """Test case for delete_attribution_report_template

        """
        pass

    def test_get_all_attribution_report_templates(self) -> None:
        """Test case for get_all_attribution_report_templates

        """
        pass

    def test_get_attribution_report_template_by_id(self) -> None:
        """Test case for get_attribution_report_template_by_id

        """
        pass

    def test_save_attribution_report_template(self) -> None:
        """Test case for save_attribution_report_template

        """
        pass


if __name__ == '__main__':
    unittest.main()
