# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr, field_validator
from typing import Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.api_applied_license_overrides_dto import ApiAppliedLicenseOverridesDTO
from sonatype_iq_api_client.models.api_license_override_dto import ApiLicenseOverrideDTO
from sonatype_iq_api_client.models.component_identifier import ComponentIdentifier

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class LicenseOverridesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def add_license_override(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to add or update a license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        api_license_override_dto: Annotated[ApiLicenseOverrideDTO, Field(description="Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiLicenseOverrideDTO:
        """add_license_override

        Use this method to add or update a license override to a component for a given owner scope.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to add or update a license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param api_license_override_dto: Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`. (required)
        :type api_license_override_dto: ApiLicenseOverrideDTO
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_license_override_dto=api_license_override_dto,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLicenseOverrideDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_license_override_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to add or update a license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        api_license_override_dto: Annotated[ApiLicenseOverrideDTO, Field(description="Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiLicenseOverrideDTO]:
        """add_license_override

        Use this method to add or update a license override to a component for a given owner scope.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to add or update a license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param api_license_override_dto: Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`. (required)
        :type api_license_override_dto: ApiLicenseOverrideDTO
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_license_override_dto=api_license_override_dto,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLicenseOverrideDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_license_override_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to add or update a license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        api_license_override_dto: Annotated[ApiLicenseOverrideDTO, Field(description="Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """add_license_override

        Use this method to add or update a license override to a component for a given owner scope.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to add or update a license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param api_license_override_dto: Enter the license override details to add or update a license override for a component. The request body should contain the following fields:  - `ownerId`: Enter the id of the application, organization or the repository.  - `comment`: Enter a comment for the license override.  - `licenseIds`: Enter the license ids for the license override.  - `componentIdentifier`: Enter the componentIdentifier consisting of format and coordinates.  - `status`: Enter the status of the license override. The possible values are `OPEN`, `ACKNOWLEDGED`, `OVERRIDDEN`, `SELECTED`, and `CONFIRMED`. (required)
        :type api_license_override_dto: ApiLicenseOverrideDTO
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            api_license_override_dto=api_license_override_dto,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiLicenseOverrideDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_license_override_serialize(
        self,
        owner_type,
        owner_id,
        api_license_override_dto,
        where,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        if where is not None:
            
            _query_params.append(('where', where))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if api_license_override_dto is not None:
            _body_params = api_license_override_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/licenseOverrides/{ownerType}/{ownerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_license_override(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to delete license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        license_override_id: Annotated[StrictStr, Field(description="Enter the id of the license override you want to delete.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """delete_license_override

        Use this method to delete a license override for a component.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to delete license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param license_override_id: Enter the id of the license override you want to delete. (required)
        :type license_override_id: str
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            license_override_id=license_override_id,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_license_override_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to delete license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        license_override_id: Annotated[StrictStr, Field(description="Enter the id of the license override you want to delete.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """delete_license_override

        Use this method to delete a license override for a component.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to delete license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param license_override_id: Enter the id of the license override you want to delete. (required)
        :type license_override_id: str
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            license_override_id=license_override_id,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_license_override_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` scope for which you want to delete license override")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        license_override_id: Annotated[StrictStr, Field(description="Enter the id of the license override you want to delete.")],
        where: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """delete_license_override

        Use this method to delete a license override for a component.  Permissions required: Change Licenses

        :param owner_type: Select the `ownerType` scope for which you want to delete license override (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param license_override_id: Enter the id of the license override you want to delete. (required)
        :type license_override_id: str
        :param where:
        :type where: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_license_override_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            license_override_id=license_override_id,
            where=where,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_license_override_serialize(
        self,
        owner_type,
        owner_id,
        license_override_id,
        where,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        if license_override_id is not None:
            _path_params['licenseOverrideId'] = license_override_id
        # process the query parameters
        if where is not None:
            
            _query_params.append(('where', where))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/licenseOverrides/{ownerType}/{ownerId}/{licenseOverrideId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_applied_license_overrides(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"}")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiAppliedLicenseOverridesDTO:
        """get_applied_license_overrides

        Use this method to retrieve the applied license overrides for a component.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param component_identifier: Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"} (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_applied_license_overrides_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"}")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiAppliedLicenseOverridesDTO]:
        """get_applied_license_overrides

        Use this method to retrieve the applied license overrides for a component.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param component_identifier: Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"} (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_applied_license_overrides_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the application, organization or the repository.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"}")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_applied_license_overrides

        Use this method to retrieve the applied license overrides for a component.  Permissions required: View IQ Elements

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the application, organization or the repository. (required)
        :type owner_id: str
        :param component_identifier: Enter the componentIdentifier consisting of format and coordinates as a JSON e.g., `?componentIdentifier={\"format\":\"maven\",\"coordinates\":\"{...}}\"} (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_applied_license_overrides_serialize(
        self,
        owner_type,
        owner_id,
        component_identifier,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        if component_identifier is not None:
            
            _query_params.append(('componentIdentifier', component_identifier))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/licenseOverrides/{ownerType}/{ownerId}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_applied_license_overrides_for_legal_reviewer(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the owner.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the component format and coordinates.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiAppliedLicenseOverridesDTO:
        """get_applied_license_overrides_for_legal_reviewer

        Use this method to retrieve the applied license overrides for a given component and owner.  Permissions required: Review Legal Obligations For Components Licenses

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the owner. (required)
        :type owner_id: str
        :param component_identifier: Enter the component format and coordinates. (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_for_legal_reviewer_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_applied_license_overrides_for_legal_reviewer_with_http_info(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the owner.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the component format and coordinates.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ApiAppliedLicenseOverridesDTO]:
        """get_applied_license_overrides_for_legal_reviewer

        Use this method to retrieve the applied license overrides for a given component and owner.  Permissions required: Review Legal Obligations For Components Licenses

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the owner. (required)
        :type owner_id: str
        :param component_identifier: Enter the component format and coordinates. (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_for_legal_reviewer_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_applied_license_overrides_for_legal_reviewer_without_preload_content(
        self,
        owner_type: Annotated[str, Field(strict=True, description="Select the `ownerType` for which you want to retrieve the applied license overrides.")],
        owner_id: Annotated[StrictStr, Field(description="Enter the id of the owner.")],
        component_identifier: Annotated[ComponentIdentifier, Field(description="Enter the component format and coordinates.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_applied_license_overrides_for_legal_reviewer

        Use this method to retrieve the applied license overrides for a given component and owner.  Permissions required: Review Legal Obligations For Components Licenses

        :param owner_type: Select the `ownerType` for which you want to retrieve the applied license overrides. (required)
        :type owner_type: str
        :param owner_id: Enter the id of the owner. (required)
        :type owner_id: str
        :param component_identifier: Enter the component format and coordinates. (required)
        :type component_identifier: ComponentIdentifier
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_applied_license_overrides_for_legal_reviewer_serialize(
            owner_type=owner_type,
            owner_id=owner_id,
            component_identifier=component_identifier,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ApiAppliedLicenseOverridesDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_applied_license_overrides_for_legal_reviewer_serialize(
        self,
        owner_type,
        owner_id,
        component_identifier,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if owner_type is not None:
            _path_params['ownerType'] = owner_type
        if owner_id is not None:
            _path_params['ownerId'] = owner_id
        # process the query parameters
        if component_identifier is not None:
            
            _query_params.append(('componentIdentifier', component_identifier))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/licenseOverrides/{ownerType}/{ownerId}/legalReviewer',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )


