# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.configure_artifactory_connection_api import ConfigureArtifactoryConnectionApi


class TestConfigureArtifactoryConnectionApi(unittest.TestCase):
    """ConfigureArtifactoryConnectionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConfigureArtifactoryConnectionApi()

    def tearDown(self) -> None:
        pass

    def test_add_artifactory_connection(self) -> None:
        """Test case for add_artifactory_connection

        """
        pass

    def test_delete_artifactory_connection(self) -> None:
        """Test case for delete_artifactory_connection

        """
        pass

    def test_get_artifactory_connection(self) -> None:
        """Test case for get_artifactory_connection

        """
        pass

    def test_get_owner_artifactory_connection(self) -> None:
        """Test case for get_owner_artifactory_connection

        """
        pass

    def test_test_artifactory_connection(self) -> None:
        """Test case for test_artifactory_connection

        """
        pass

    def test_test_artifactory_connection1(self) -> None:
        """Test case for test_artifactory_connection1

        """
        pass

    def test_update_artifactory_connection(self) -> None:
        """Test case for update_artifactory_connection

        """
        pass

    def test_update_owner_artifactory_connection_status(self) -> None:
        """Test case for update_owner_artifactory_connection_status

        """
        pass


if __name__ == '__main__':
    unittest.main()
