# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.auto_policy_waiver_exclusions_api import AutoPolicyWaiverExclusionsApi


class TestAutoPolicyWaiverExclusionsApi(unittest.TestCase):
    """AutoPolicyWaiverExclusionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AutoPolicyWaiverExclusionsApi()

    def tearDown(self) -> None:
        pass

    def test_add_auto_policy_waive_exclusion(self) -> None:
        """Test case for add_auto_policy_waive_exclusion

        """
        pass

    def test_delete_auto_policy_waiver_exclusion(self) -> None:
        """Test case for delete_auto_policy_waiver_exclusion

        """
        pass

    def test_get_auto_policy_waiver_exclusions(self) -> None:
        """Test case for get_auto_policy_waiver_exclusions

        """
        pass


if __name__ == '__main__':
    unittest.main()
