# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_owner_artifactory_connection_dto import ApiOwnerArtifactoryConnectionDTO

class TestApiOwnerArtifactoryConnectionDTO(unittest.TestCase):
    """ApiOwnerArtifactoryConnectionDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiOwnerArtifactoryConnectionDTO:
        """Test ApiOwnerArtifactoryConnectionDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiOwnerArtifactoryConnectionDTO`
        """
        model = ApiOwnerArtifactoryConnectionDTO()
        if include_optional:
            return ApiOwnerArtifactoryConnectionDTO(
                artifactory_connection = sonatype_iq_api_client.models.api_artifactory_connection_dto.ApiArtifactoryConnectionDTO(
                    artifactory_connection_id = '', 
                    base_url = '', 
                    is_anonymous = True, 
                    owner_id = '', 
                    owner_type = 'application', 
                    password = '', 
                    username = '', ),
                artifactory_connection_status = sonatype_iq_api_client.models.api_artifactory_connection_status_response_dto.ApiArtifactoryConnectionStatusResponseDTO(
                    allow_change = True, 
                    allow_override = True, 
                    enabled = True, 
                    inherited_from_org_enabled = True, 
                    inherited_from_organization_id = '', 
                    inherited_from_organization_name = '', ),
                owner_dto = sonatype_iq_api_client.models.api_owner_dto.ApiOwnerDTO(
                    owner_id = '', 
                    owner_name = '', 
                    owner_public_id = '', 
                    owner_type = '', )
            )
        else:
            return ApiOwnerArtifactoryConnectionDTO(
        )
        """

    def testApiOwnerArtifactoryConnectionDTO(self):
        """Test ApiOwnerArtifactoryConnectionDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
