# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from sonatype_iq_api_client.models.search_result_item_dto import SearchResultItemDTO
from typing import Optional, Set
from typing_extensions import Self

class GroupingByDTO(BaseModel):
    """
    GroupingByDTO
    """ # noqa: E501
    additional_info: Optional[StrictStr] = Field(default=None, alias="additionalInfo")
    group_by: Optional[StrictStr] = Field(default=None, alias="groupBy")
    group_identifier: Optional[StrictStr] = Field(default=None, alias="groupIdentifier")
    search_result_item_dtos: Optional[List[SearchResultItemDTO]] = Field(default=None, alias="searchResultItemDTOS")
    __properties: ClassVar[List[str]] = ["additionalInfo", "groupBy", "groupIdentifier", "searchResultItemDTOS"]

    @field_validator('group_identifier')
    def group_identifier_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['itemType', 'organizationId', 'organizationName', 'applicationId', 'applicationName', 'applicationPublicId', 'policyEvaluationStage', 'applicationVersion', 'reportId', 'componentHash', 'componentFormat', 'componentName', 'componentCoordinate', 'vulnerabilityId', 'vulnerabilitySeverity', 'vulnerabilityStatus', 'vulnerabilityDescription', 'applicationCategoryId', 'applicationCategoryName', 'applicationCategoryColor', 'applicationCategoryDescription', 'componentLabelId', 'componentLabelName', 'componentLabelColor', 'componentLabelDescription', 'policyId', 'policyName', 'policyThreatCategory', 'policyThreatLevel', 'parentOrganizationName', 'parentOrganizationId', 'sbomSpecification']):
            raise ValueError("must be one of enum values ('itemType', 'organizationId', 'organizationName', 'applicationId', 'applicationName', 'applicationPublicId', 'policyEvaluationStage', 'applicationVersion', 'reportId', 'componentHash', 'componentFormat', 'componentName', 'componentCoordinate', 'vulnerabilityId', 'vulnerabilitySeverity', 'vulnerabilityStatus', 'vulnerabilityDescription', 'applicationCategoryId', 'applicationCategoryName', 'applicationCategoryColor', 'applicationCategoryDescription', 'componentLabelId', 'componentLabelName', 'componentLabelColor', 'componentLabelDescription', 'policyId', 'policyName', 'policyThreatCategory', 'policyThreatLevel', 'parentOrganizationName', 'parentOrganizationId', 'sbomSpecification')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GroupingByDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in search_result_item_dtos (list)
        _items = []
        if self.search_result_item_dtos:
            for _item_search_result_item_dtos in self.search_result_item_dtos:
                if _item_search_result_item_dtos:
                    _items.append(_item_search_result_item_dtos.to_dict())
            _dict['searchResultItemDTOS'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GroupingByDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "additionalInfo": obj.get("additionalInfo"),
            "groupBy": obj.get("groupBy"),
            "groupIdentifier": obj.get("groupIdentifier"),
            "searchResultItemDTOS": [SearchResultItemDTO.from_dict(_item) for _item in obj["searchResultItemDTOS"]] if obj.get("searchResultItemDTOS") is not None else None
        })
        return _obj


