# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.applications_api import ApplicationsApi


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationsApi()

    def tearDown(self) -> None:
        pass

    def test_add_application(self) -> None:
        """Test case for add_application

        """
        pass

    def test_clone_application(self) -> None:
        """Test case for clone_application

        """
        pass

    def test_delete_application(self) -> None:
        """Test case for delete_application

        """
        pass

    def test_get_application(self) -> None:
        """Test case for get_application

        """
        pass

    def test_get_applications(self) -> None:
        """Test case for get_applications

        """
        pass

    def test_get_applications_by_organization_id(self) -> None:
        """Test case for get_applications_by_organization_id

        """
        pass

    def test_move_application(self) -> None:
        """Test case for move_application

        """
        pass

    def test_update_application(self) -> None:
        """Test case for update_application

        """
        pass


if __name__ == '__main__':
    unittest.main()
