# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.reports_api import ReportsApi


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ReportsApi()

    def tearDown(self) -> None:
        pass

    def test_get_all1(self) -> None:
        """Test case for get_all1

        """
        pass

    def test_get_by_application_id(self) -> None:
        """Test case for get_by_application_id

        """
        pass

    def test_get_components_in_quarantine(self) -> None:
        """Test case for get_components_in_quarantine

        """
        pass

    def test_get_components_with_waivers(self) -> None:
        """Test case for get_components_with_waivers

        """
        pass

    def test_get_metrics(self) -> None:
        """Test case for get_metrics

        """
        pass

    def test_get_report_history_for_application(self) -> None:
        """Test case for get_report_history_for_application

        """
        pass

    def test_get_stale_waivers(self) -> None:
        """Test case for get_stale_waivers

        """
        pass


if __name__ == '__main__':
    unittest.main()
