# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_metrics_reporting_dtov2 import ApiMetricsReportingDTOV2

class TestApiMetricsReportingDTOV2(unittest.TestCase):
    """ApiMetricsReportingDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiMetricsReportingDTOV2:
        """Test ApiMetricsReportingDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiMetricsReportingDTOV2`
        """
        model = ApiMetricsReportingDTOV2()
        if include_optional:
            return ApiMetricsReportingDTOV2(
                aggregations = [
                    sonatype_iq_api_client.models.api_metrics_reporting_aggregation_dtov2.ApiMetricsReportingAggregationDTOV2(
                        discovered_counts = {
                            'key' : {
                                'key' : 56
                                }
                            }, 
                        evaluation_count = 56, 
                        fixed_counts = {
                            'key' : {
                                'key' : 56
                                }
                            }, 
                        mttr_critical_threat = 56, 
                        mttr_low_threat = 56, 
                        mttr_moderate_threat = 56, 
                        mttr_severe_threat = 56, 
                        open_counts_at_time_period_end = {
                            'key' : {
                                'key' : 56
                                }
                            }, 
                        time_period_start = '', 
                        waived_counts = {
                            'key' : {
                                'key' : 56
                                }
                            }, )
                    ],
                application_id = '',
                application_name = '',
                application_public_id = '',
                organization_id = '',
                organization_name = ''
            )
        else:
            return ApiMetricsReportingDTOV2(
        )
        """

    def testApiMetricsReportingDTOV2(self):
        """Test ApiMetricsReportingDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
