# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.policy_violation_details_api import PolicyViolationDetailsApi


class TestPolicyViolationDetailsApi(unittest.TestCase):
    """PolicyViolationDetailsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PolicyViolationDetailsApi()

    def tearDown(self) -> None:
        pass

    def test_get_applicable_auto_waiver(self) -> None:
        """Test case for get_applicable_auto_waiver

        """
        pass

    def test_get_applicable_waiver_requests(self) -> None:
        """Test case for get_applicable_waiver_requests

        """
        pass

    def test_get_applicable_waivers(self) -> None:
        """Test case for get_applicable_waivers

        """
        pass

    def test_get_cross_stage_policy_violation_by_constituent_id(self) -> None:
        """Test case for get_cross_stage_policy_violation_by_constituent_id

        """
        pass

    def test_get_cross_stage_policy_violation_by_id(self) -> None:
        """Test case for get_cross_stage_policy_violation_by_id

        """
        pass

    def test_get_policy_violations(self) -> None:
        """Test case for get_policy_violations

        """
        pass

    def test_get_similar_waivers(self) -> None:
        """Test case for get_similar_waivers

        """
        pass

    def test_get_transitive_policy_violations_by_app_scan_component(self) -> None:
        """Test case for get_transitive_policy_violations_by_app_scan_component

        """
        pass

    def test_get_transitive_policy_violations_by_owner_stage_component(self) -> None:
        """Test case for get_transitive_policy_violations_by_owner_stage_component

        """
        pass


if __name__ == '__main__':
    unittest.main()
