# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_composite_source_control_dto import ApiCompositeSourceControlDTO

class TestApiCompositeSourceControlDTO(unittest.TestCase):
    """ApiCompositeSourceControlDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiCompositeSourceControlDTO:
        """Test ApiCompositeSourceControlDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiCompositeSourceControlDTO`
        """
        model = ApiCompositeSourceControlDTO()
        if include_optional:
            return ApiCompositeSourceControlDTO(
                base_branch = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', ),
                close_pr_after_days = sonatype_iq_api_client.models.api_composite_value_dto_integer.ApiCompositeValueDTOInteger(
                    parent_name = '', 
                    parent_value = 56, 
                    value = 56, ),
                close_pr_after_days_open_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                close_pr_on_failed_checks_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                commit_status_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                id = '',
                inner_source_automated_updates_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                manual_pull_requests_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                owner_id = '',
                provider = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', ),
                pull_request_commenting_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                remediation_pull_requests_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                repository_url = '',
                source_control_evaluations_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                source_control_scan_target = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', ),
                ssh_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                status_checks_enabled = sonatype_iq_api_client.models.api_composite_value_dto_boolean.ApiCompositeValueDTOBoolean(
                    parent_name = '', 
                    parent_value = True, 
                    value = True, ),
                token = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', ),
                username = sonatype_iq_api_client.models.api_composite_value_dto_string.ApiCompositeValueDTOString(
                    parent_name = '', 
                    parent_value = '', 
                    value = '', )
            )
        else:
            return ApiCompositeSourceControlDTO(
        )
        """

    def testApiCompositeSourceControlDTO(self):
        """Test ApiCompositeSourceControlDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
