# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_search_results_dtov2 import ApiSearchResultsDTOV2

class TestApiSearchResultsDTOV2(unittest.TestCase):
    """ApiSearchResultsDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSearchResultsDTOV2:
        """Test ApiSearchResultsDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSearchResultsDTOV2`
        """
        model = ApiSearchResultsDTOV2()
        if include_optional:
            return ApiSearchResultsDTOV2(
                criteria = sonatype_iq_api_client.models.api_search_criteria_dtov2.ApiSearchCriteriaDTOV2(
                    component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                        coordinates = {
                            'key' : ''
                            }, 
                        format = '', ), 
                    hash = '', 
                    package_url = '', 
                    stage_id = '', ),
                results = [
                    sonatype_iq_api_client.models.api_search_result_dtov2.ApiSearchResultDTOV2(
                        application_id = '', 
                        application_name = '', 
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        dependency_data = sonatype_iq_api_client.models.api_dependency_data_dto.ApiDependencyDataDTO(
                            direct_dependency = True, 
                            inner_source = True, 
                            inner_source_data = [
                                sonatype_iq_api_client.models.inner_source_data.InnerSourceData(
                                    inner_source_component_purl = '', 
                                    owner_application_id = '', 
                                    owner_application_name = '', )
                                ], 
                            parent_component_purls = [
                                ''
                                ], ), 
                        hash = '', 
                        package_url = '', 
                        report_html_url = '', 
                        report_url = '', 
                        threat_level = 56, )
                    ]
            )
        else:
            return ApiSearchResultsDTOV2(
        )
        """

    def testApiSearchResultsDTOV2(self):
        """Test ApiSearchResultsDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
