# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_component_project_data_dto import ApiComponentProjectDataDTO

class TestApiComponentProjectDataDTO(unittest.TestCase):
    """ApiComponentProjectDataDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiComponentProjectDataDTO:
        """Test ApiComponentProjectDataDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiComponentProjectDataDTO`
        """
        model = ApiComponentProjectDataDTO()
        if include_optional:
            return ApiComponentProjectDataDTO(
                first_release_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_release_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                project_metadata = sonatype_iq_api_client.models.api_component_project_metadata_dto.ApiComponentProjectMetadataDTO(
                    description = '', 
                    organization = '', ),
                source_control_management = sonatype_iq_api_client.models.api_component_project_scm_dto.ApiComponentProjectScmDTO(
                    scm_details = sonatype_iq_api_client.models.api_component_project_scm_details_dto.ApiComponentProjectScmDetailsDTO(
                        commits_per_month = 56, 
                        unique_devs_per_month = 56, ), 
                    scm_metadata = sonatype_iq_api_client.models.api_component_project_scm_metadata_dto.ApiComponentProjectScmMetadataDTO(
                        forks = 56, 
                        stars = 56, ), 
                    scm_url = '', )
            )
        else:
            return ApiComponentProjectDataDTO(
        )
        """

    def testApiComponentProjectDataDTO(self):
        """Test ApiComponentProjectDataDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
