# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.197.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_firewall_quarantined_component_dto_result import ApiFirewallQuarantinedComponentDtoResult

class TestApiFirewallQuarantinedComponentDtoResult(unittest.TestCase):
    """ApiFirewallQuarantinedComponentDtoResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiFirewallQuarantinedComponentDtoResult:
        """Test ApiFirewallQuarantinedComponentDtoResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiFirewallQuarantinedComponentDtoResult`
        """
        model = ApiFirewallQuarantinedComponentDtoResult()
        if include_optional:
            return ApiFirewallQuarantinedComponentDtoResult(
                page = 56,
                page_count = 56,
                page_size = 56,
                results = [
                    sonatype_iq_api_client.models.api_firewall_quarantined_component_dto.ApiFirewallQuarantinedComponentDto(
                        component_identifier = sonatype_iq_api_client.models.component_identifier.ComponentIdentifier(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        display_name = '', 
                        hash = '', 
                        match_state = '', 
                        pathname = '', 
                        policy_name = '', 
                        quarantine_date = '', 
                        quarantined = True, 
                        repository_id = '', 
                        repository_name = '', 
                        threat_level = 56, )
                    ],
                total = 56
            )
        else:
            return ApiFirewallQuarantinedComponentDtoResult(
        )
        """

    def testApiFirewallQuarantinedComponentDtoResult(self):
        """Test ApiFirewallQuarantinedComponentDtoResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
